@@ -1,16 +1,16 @@
 import pytest
 
-from cattr import Converter, GenConverter
+from cattr import BaseConverter, Converter
 
 
-@pytest.mark.parametrize("converter_cls", [Converter, GenConverter])
+@pytest.mark.parametrize("converter_cls", [BaseConverter, Converter])
 def test_unstructure_int(benchmark, converter_cls):
     c = converter_cls()
 
     benchmark(c.unstructure, 5)
 
 
-@pytest.mark.parametrize("converter_cls", [Converter, GenConverter])
+@pytest.mark.parametrize("converter_cls", [BaseConverter, Converter])
 def test_unstructure_float(benchmark, converter_cls):
     c = converter_cls()
 
