@@ -1,13 +1,13 @@
+from cattrs.cols import iterable_unstructure_factory as make_iterable_unstructure_fn
 from cattrs.gen import (
-    AttributeOverride,
     make_dict_structure_fn,
     make_dict_unstructure_fn,
     make_hetero_tuple_unstructure_fn,
-    make_iterable_unstructure_fn,
     make_mapping_structure_fn,
     make_mapping_unstructure_fn,
     override,
 )
+from cattrs.gen._consts import AttributeOverride
 
 __all__ = [
     "AttributeOverride",
