@@ -1,4 +1,5 @@
 """Preconfigured converters for pyyaml."""
-from cattrs.preconf.pyyaml import configure_converter, make_converter, PyyamlConverter
+
+from cattrs.preconf.pyyaml import PyyamlConverter, configure_converter, make_converter
 
 __all__ = ["configure_converter", "make_converter", "PyyamlConverter"]
