@@ -1,4 +1,5 @@
 """Preconfigured converters for tomlkit."""
-from cattrs.preconf.tomlkit import configure_converter, make_converter, TomlkitConverter
+
+from cattrs.preconf.tomlkit import TomlkitConverter, configure_converter, make_converter
 
 __all__ = ["configure_converter", "make_converter", "TomlkitConverter"]
