@@ -1,8 +1,9 @@
 """Tests for generated dict functions."""
+
 from typing import Dict, Type
 
 import pytest
-from attrs import NOTHING, Factory, define, field
+from attrs import NOTHING, Factory, define, field, frozen
 from hypothesis import assume, given
 from hypothesis.strategies import data, just, one_of, sampled_from
 
@@ -93,10 +94,9 @@ def test_nodefs_generated_unstructuring_cl(
             else:
                 # The default is a factory, but might take self.
                 if attr.default.takes_self:
-                    if val == attr.default.factory(cl):
-                        assert attr.name not in res
-                    else:
-                        assert attr.name in res
+                    # Our strategies can only produce these for now.
+                    assert val == attr.default.factory(cl)
+                    assert attr.name not in res
                 else:
                     if val == attr.default.factory():
                         assert attr.name not in res
@@ -151,10 +151,7 @@ def test_individual_overrides(converter_cls, cl_and_vals):
                     assert attr.name in res
             else:
                 if attr.default.takes_self:
-                    if val == attr.default.factory(inst):
-                        assert attr.name not in res
-                    else:
-                        assert attr.name in res
+                    assert attr.name not in res
                 else:
                     if val == attr.default.factory():
                         assert attr.name not in res
@@ -172,6 +169,7 @@ def test_unmodified_generated_structuring(cl_and_vals, dv: bool):
     converter = Converter(detailed_validation=dv)
     cl, vals, kwargs = cl_and_vals
     fn = make_dict_structure_fn(cl, converter, _cattrs_detailed_validation=dv)
+    assert fn.overrides == {}
 
     inst = cl(*vals, **kwargs)
 
@@ -202,6 +200,8 @@ def test_renaming(cl_and_vals, data):
     s_fn = make_dict_structure_fn(
         cl, converter, **{to_replace.name: override(rename="class")}
     )
+    assert s_fn.overrides == {to_replace.name: override(rename="class")}
+    assert u_fn.overrides == {to_replace.name: override(rename="class")}
 
     converter.register_structure_hook(cl, s_fn)
     converter.register_unstructure_hook(cl, u_fn)
@@ -448,12 +448,18 @@ def test_init_false(converter: BaseConverter) -> None:
 def test_init_false_overridden(converter: BaseConverter) -> None:
     """init=False handling can be overriden."""
 
+    @frozen
+    class Inner:
+        a: int
+
     @define
     class A:
         a: int
         b: int = field(init=False)
         _c: int = field(init=False)
-        d: int = field(init=False, default=4)
+        d: Inner = field(init=False)
+        e: int = field(init=False, default=4)
+        f: Inner = field(init=False, default=Inner(1))
 
     converter.register_unstructure_hook(
         A, make_dict_unstructure_fn(A, converter, _cattrs_include_init_false=True)
@@ -462,28 +468,36 @@ def test_init_false_overridden(converter: BaseConverter) -> None:
     a = A(1)
     a.b = 2
     a._c = 3
+    a.d = Inner(4)
 
-    assert converter.unstructure(a) == {"a": 1, "b": 2, "_c": 3, "d": 4}
+    assert converter.unstructure(a) == {
+        "a": 1,
+        "b": 2,
+        "_c": 3,
+        "d": {"a": 4},
+        "e": 4,
+        "f": {"a": 1},
+    }
 
     converter.register_structure_hook(
-        A,
-        make_dict_structure_fn(
-            A,
-            converter,
-            _cattrs_include_init_false=True,
-            _cattrs_detailed_validation=converter.detailed_validation,
-        ),
+        A, make_dict_structure_fn(A, converter, _cattrs_include_init_false=True)
     )
 
-    structured = converter.structure({"a": 1, "b": 2, "_c": 3}, A)
+    structured = converter.structure({"a": 1, "b": 2, "_c": 3, "d": {"a": 1}}, A)
     assert structured.b == 2
     assert structured._c == 3
-    assert structured.d == 4
+    assert structured.d == Inner(1)
+    assert structured.e == 4
+    assert structured.f == Inner(1)
 
-    structured = converter.structure({"a": 1, "b": 2, "_c": 3, "d": -4}, A)
+    structured = converter.structure(
+        {"a": 1, "b": 2, "_c": 3, "d": {"a": 5}, "e": -4, "f": {"a": 2}}, A
+    )
     assert structured.b == 2
     assert structured._c == 3
-    assert structured.d == -4
+    assert structured.d == Inner(5)
+    assert structured.e == -4
+    assert structured.f == Inner(2)
 
 
 def test_init_false_field_override(converter: BaseConverter) -> None:
@@ -536,6 +550,29 @@ def test_init_false_field_override(converter: BaseConverter) -> None:
     assert structured.d == -4
 
 
+def test_init_false_no_structure_hook(converter: BaseConverter):
+    """init=False attributes with converters and `prefer_attrs_converters` work."""
+
+    @define
+    class A:
+        a: int = field(converter=int, init=False)
+
+    converter.register_structure_hook(
+        A,
+        make_dict_structure_fn(
+            A,
+            converter,
+            _cattrs_prefer_attrib_converters=True,
+            _cattrs_include_init_false=True,
+        ),
+    )
+
+    res = A()
+    res.a = 5
+
+    assert converter.structure({"a": "5"}, A) == res
+
+
 @given(forbid_extra_keys=..., detailed_validation=...)
 def test_forbid_extra_keys_from_converter(
     forbid_extra_keys: bool, detailed_validation: bool
@@ -595,3 +632,29 @@ def test_detailed_validation_from_converter(converter: BaseConverter):
     else:
         with pytest.raises(ValueError):
             converter.structure({"a": "a"}, A)
+
+
+@given(prefer=...)
+def test_prefer_converters_from_converter(prefer: bool):
+    """
+    `prefer_attrs_converters` is taken from the converter by default.
+    """
+
+    @define
+    class A:
+        a: int = field(converter=lambda x: x + 1)
+
+    converter = BaseConverter(prefer_attrib_converters=prefer)
+    converter.register_structure_hook(int, lambda x, _: x + 1)
+    converter.register_structure_hook(A, make_dict_structure_fn(A, converter))
+
+    if prefer:
+        assert converter.structure({"a": 1}, A).a == 2
+    else:
+        assert converter.structure({"a": 1}, A).a == 3
+
+
+def test_fields_exception():
+    """fields() raises on a non-attrs, non-dataclass class."""
+    with pytest.raises(Exception):  # noqa: B017
+        fields(int)
