@@ -1,14 +1,22 @@
-from typing import Dict, Generic, List, Optional, TypeVar, Union
+from collections import deque
+from typing import Deque, Dict, Generic, List, Optional, TypeVar, Union
 
 import pytest
-from attr import asdict, attrs, define
+from attrs import asdict, define
 
 from cattrs import BaseConverter, Converter
-from cattrs._compat import Protocol, is_py39_plus
+from cattrs._compat import Protocol
 from cattrs._generics import deep_copy_with
 from cattrs.errors import StructureHandlerNotFoundError
+from cattrs.gen._generics import generate_mapping
 
-from ._compat import Dict_origin, List_origin
+from ._compat import (
+    Dict_origin,
+    List_origin,
+    is_py39_plus,
+    is_py310_plus,
+    is_py311_plus,
+)
 
 T = TypeVar("T")
 T2 = TypeVar("T2")
@@ -73,7 +81,7 @@ def test_structure_generics_with_cols(t, result, detailed_validation):
 @pytest.mark.parametrize(
     ("t", "result"), ((int, (1, [2], {"3": 3})), (str, ("1", ["2"], {"3": "3"})))
 )
-def test_39_structure_generics_with_cols(t, result):
+def test_39_structure_generics_with_cols(t, result, genconverter: Converter):
     @define
     class GenericCols(Generic[T]):
         a: T
@@ -82,13 +90,13 @@ def test_39_structure_generics_with_cols(t, result):
 
     expected = GenericCols(*result)
 
-    res = Converter().structure(asdict(expected), GenericCols[t])
+    res = genconverter.structure(asdict(expected), GenericCols[t])
 
     assert res == expected
 
 
 @pytest.mark.parametrize(("t", "result"), ((int, (1, [1, 2, 3])), (int, (1, None))))
-def test_structure_nested_generics_with_cols(t, result):
+def test_structure_nested_generics_with_cols(t, result, genconverter: Converter):
     @define
     class GenericCols(Generic[T]):
         a: T
@@ -96,7 +104,7 @@ def test_structure_nested_generics_with_cols(t, result):
 
     expected = GenericCols(*result)
 
-    res = Converter().structure(asdict(expected), GenericCols[t])
+    res = genconverter.structure(asdict(expected), GenericCols[t])
 
     assert res == expected
 
@@ -124,7 +132,7 @@ def test_able_to_structure_deeply_nested_generics_gen(converter):
 
 
 def test_structure_unions_of_generics(converter):
-    @attrs(auto_attribs=True)
+    @define
     class TClass2(Generic[T]):
         c: T
 
@@ -134,7 +142,7 @@ def test_structure_unions_of_generics(converter):
 
 
 def test_structure_list_of_generic_unions(converter):
-    @attrs(auto_attribs=True)
+    @define
     class TClass2(Generic[T]):
         c: T
 
@@ -145,7 +153,21 @@ def test_structure_list_of_generic_unions(converter):
     assert res == data
 
 
-def test_raises_if_no_generic_params_supplied(converter):
+def test_structure_deque_of_generic_unions(converter):
+    @define
+    class TClass2(Generic[T]):
+        c: T
+
+    data = deque((TClass2(c="string"), TClass(1, 2)))
+    res = converter.structure(
+        [asdict(x) for x in data], Deque[Union[TClass[int, int], TClass2[str]]]
+    )
+    assert res == data
+
+
+def test_raises_if_no_generic_params_supplied(
+    converter: Union[Converter, BaseConverter]
+):
     data = TClass(1, "a")
 
     with pytest.raises(
@@ -157,35 +179,44 @@ def test_raises_if_no_generic_params_supplied(converter):
     assert exc.value.type_ is T
 
 
-def test_unstructure_generic_attrs():
-    c = Converter()
-
-    @attrs(auto_attribs=True)
+def test_unstructure_generic_attrs(genconverter):
+    @define
     class Inner(Generic[T]):
         a: T
 
-    @attrs(auto_attribs=True)
+    inner = Inner(Inner(1))
+    assert genconverter.unstructure(inner) == {"a": {"a": 1}}
+
+    @define
     class Outer:
         inner: Inner[int]
 
     initial = Outer(Inner(1))
-    raw = c.unstructure(initial)
+    raw = genconverter.unstructure(initial)
 
     assert raw == {"inner": {"a": 1}}
 
-    new = c.structure(raw, Outer)
+    new = genconverter.structure(raw, Outer)
     assert initial == new
 
-    @attrs(auto_attribs=True)
+    @define
     class OuterStr:
         inner: Inner[str]
 
-    assert c.structure(raw, OuterStr) == OuterStr(Inner("1"))
+    assert genconverter.structure(raw, OuterStr) == OuterStr(Inner("1"))
 
 
-def test_unstructure_deeply_nested_generics():
-    c = Converter()
+def test_unstructure_optional(genconverter):
+    """Generics with optional fields work."""
 
+    @define
+    class C(Generic[T]):
+        a: Union[T, None]
+
+    assert genconverter.unstructure(C(C(1))) == {"a": {"a": 1}}
+
+
+def test_unstructure_deeply_nested_generics(genconverter):
     @define
     class Inner:
         a: int
@@ -195,16 +226,14 @@ def test_unstructure_deeply_nested_generics():
         inner: T
 
     initial = Outer[Inner](Inner(1))
-    raw = c.unstructure(initial, Outer[Inner])
+    raw = genconverter.unstructure(initial, Outer[Inner])
     assert raw == {"inner": {"a": 1}}
 
-    raw = c.unstructure(initial)
+    raw = genconverter.unstructure(initial)
     assert raw == {"inner": {"a": 1}}
 
 
-def test_unstructure_deeply_nested_generics_list():
-    c = Converter()
-
+def test_unstructure_deeply_nested_generics_list(genconverter):
     @define
     class Inner:
         a: int
@@ -214,16 +243,14 @@ def test_unstructure_deeply_nested_generics_list():
         inner: List[T]
 
     initial = Outer[Inner]([Inner(1)])
-    raw = c.unstructure(initial, Outer[Inner])
+    raw = genconverter.unstructure(initial, Outer[Inner])
     assert raw == {"inner": [{"a": 1}]}
 
-    raw = c.unstructure(initial)
+    raw = genconverter.unstructure(initial)
     assert raw == {"inner": [{"a": 1}]}
 
 
-def test_unstructure_protocol():
-    c = Converter()
-
+def test_unstructure_protocol(genconverter):
     class Proto(Protocol):
         a: int
 
@@ -236,8 +263,79 @@ def test_unstructure_protocol():
         inner: Proto
 
     initial = Outer(Inner(1))
-    raw = c.unstructure(initial, Outer)
+    raw = genconverter.unstructure(initial, Outer)
     assert raw == {"inner": {"a": 1}}
 
-    raw = c.unstructure(initial)
+    raw = genconverter.unstructure(initial)
     assert raw == {"inner": {"a": 1}}
+
+
+@pytest.mark.skipif(not is_py310_plus, reason="3.10+ union syntax")
+def test_roundtrip_generic_with_union() -> None:
+    """Generators should handle classes with unions in their names."""
+    c = Converter()
+
+    @define
+    class A:
+        a: int
+
+    @define
+    class B:
+        b: int
+
+    @define
+    class Outer(Generic[T]):
+        member: T
+
+    raw = c.unstructure(Outer(A(1)), unstructure_as=Outer[A | B])
+    assert c.structure(raw, Outer[A | B]) == Outer(A(1))
+
+
+@pytest.mark.skipif(not is_py311_plus, reason="3.11+ only")
+def test_generate_typeddict_mapping() -> None:
+    from typing import Generic, TypedDict, TypeVar
+
+    T = TypeVar("T")
+    U = TypeVar("U")
+
+    class A(TypedDict):
+        pass
+
+    assert generate_mapping(A, {}) == {}
+
+    class A(TypedDict, Generic[T]):
+        a: T
+
+    assert generate_mapping(A[int], {}) == {T.__name__: int}
+
+    class B(A[int]):
+        pass
+
+    assert generate_mapping(B, {}) == {T.__name__: int}
+
+    class C(Generic[T, U]):
+        a: T
+        c: U
+
+    assert generate_mapping(C[int, U], {}) == {T.__name__: int}
+
+
+def test_nongeneric_protocols(converter):
+    """Non-generic protocols work."""
+
+    class NongenericProtocol(Protocol): ...
+
+    @define
+    class Entity(NongenericProtocol): ...
+
+    assert generate_mapping(Entity) == {}
+
+    class GenericProtocol(Protocol[T]): ...
+
+    @define
+    class GenericEntity(GenericProtocol[int]):
+        a: int
+
+    assert generate_mapping(GenericEntity) == {"T": int}
+
+    assert converter.structure({"a": 1}, GenericEntity) == GenericEntity(1)
