@@ -4,7 +4,7 @@ from enum import Enum, IntEnum, unique
 from json import dumps as json_dumps
 from json import loads as json_loads
 from platform import python_implementation
-from typing import Any, Dict, List, NewType, Tuple, Union
+from typing import Any, Dict, List, NamedTuple, NewType, Tuple, Union
 
 import pytest
 from attrs import define
@@ -35,7 +35,6 @@ from cattrs._compat import (
     AbstractSet,
     Counter,
     FrozenSet,
-    FrozenSetSubscriptable,
     Mapping,
     MutableMapping,
     MutableSequence,
@@ -48,7 +47,6 @@ from cattrs.preconf.bson import make_converter as bson_make_converter
 from cattrs.preconf.cbor2 import make_converter as cbor2_make_converter
 from cattrs.preconf.json import make_converter as json_make_converter
 from cattrs.preconf.msgpack import make_converter as msgpack_make_converter
-from cattrs.preconf.pyyaml import make_converter as pyyaml_make_converter
 from cattrs.preconf.tomlkit import make_converter as tomlkit_make_converter
 from cattrs.preconf.ujson import make_converter as ujson_make_converter
 
@@ -63,6 +61,10 @@ class B:
     b: str
 
 
+class C(NamedTuple):
+    c: float
+
+
 @define
 class Everything:
     @unique
@@ -98,6 +100,7 @@ class Everything:
     native_union: Union[int, float, str]
     native_union_with_spillover: Union[int, str, Set[str]]
     native_union_with_union_spillover: Union[int, str, A, B]
+    a_namedtuple: C
 
 
 @composite
@@ -121,9 +124,9 @@ def everythings(
     )
     strings = text(
         characters(
-            blacklist_categories=("Cs",)
-            if allow_control_characters_in_values
-            else ("Cs", "Cc")
+            blacklist_categories=(
+                ("Cs",) if allow_control_characters_in_values else ("Cs", "Cc")
+            )
         )
     )
     dts = datetimes(
@@ -166,6 +169,7 @@ def everythings(
         draw(one_of(ints, fs, strings)),
         draw(one_of(ints, strings, sets(strings))),
         draw(one_of(ints, strings, ints.map(A), strings.map(B))),
+        draw(fs.map(C)),
     )
 
 
@@ -296,7 +300,6 @@ def test_stdlib_json_converter_unstruct_collection_overrides(everything: Everyth
         include_bytes=False,
         include_datetimes=False,
         include_bools=sys.version_info[:2] != (3, 8),  # Literal issues on 3.8
-        include_literals=sys.version_info >= (3, 8),
     ),
     detailed_validation=...,
 )
@@ -314,7 +317,6 @@ def test_stdlib_json_unions(union_and_val: tuple, detailed_validation: bool):
         include_strings=False,
         include_bytes=False,
         include_bools=sys.version_info[:2] != (3, 8),  # Literal issues on 3.8
-        include_literals=sys.version_info >= (3, 8),
     ),
     detailed_validation=...,
 )
@@ -376,7 +378,6 @@ def test_ujson_converter_unstruct_collection_overrides(everything: Everything):
         include_bytes=False,
         include_datetimes=False,
         include_bools=sys.version_info[:2] != (3, 8),  # Literal issues on 3.8
-        include_literals=sys.version_info >= (3, 8),
     ),
     detailed_validation=...,
 )
@@ -445,7 +446,6 @@ def test_orjson_converter_unstruct_collection_overrides(everything: Everything):
         include_bytes=False,
         include_datetimes=False,
         include_bools=sys.version_info[:2] != (3, 8),  # Literal issues on 3.8
-        include_literals=sys.version_info >= (3, 8),
     ),
     detailed_validation=...,
 )
@@ -494,7 +494,6 @@ def test_msgpack_converter_unstruct_collection_overrides(everything: Everything)
     union_and_val=native_unions(
         include_datetimes=False,
         include_bools=sys.version_info[:2] != (3, 8),  # Literal issues on 3.8
-        include_literals=sys.version_info >= (3, 8),
     ),
     detailed_validation=...,
 )
@@ -569,7 +568,6 @@ def test_bson_converter_unstruct_collection_overrides(everything: Everything):
     union_and_val=native_unions(
         include_objectids=True,
         include_bools=sys.version_info[:2] != (3, 8),  # Literal issues on 3.8
-        include_literals=sys.version_info >= (3, 8),
     ),
     detailed_validation=...,
 )
@@ -581,65 +579,6 @@ def test_bson_unions(union_and_val: tuple, detailed_validation: bool):
     assert converter.structure(val, type) == val
 
 
-@given(everythings())
-def test_pyyaml(everything: Everything):
-    from yaml import safe_dump, safe_load
-
-    converter = pyyaml_make_converter()
-    unstructured = converter.unstructure(everything)
-    raw = safe_dump(unstructured)
-    assert converter.structure(safe_load(raw), Everything) == everything
-
-
-@given(everythings())
-def test_pyyaml_converter(everything: Everything):
-    converter = pyyaml_make_converter()
-    raw = converter.dumps(everything)
-    assert converter.loads(raw, Everything) == everything
-
-
-@given(everythings())
-def test_pyyaml_converter_unstruct_collection_overrides(everything: Everything):
-    converter = pyyaml_make_converter(
-        unstruct_collection_overrides={FrozenSetSubscriptable: sorted}
-    )
-    raw = converter.unstructure(everything)
-    assert raw["a_frozenset"] == sorted(raw["a_frozenset"])
-
-
-@given(
-    union_and_val=native_unions(
-        include_bools=sys.version_info[:2] != (3, 8),  # Literal issues on 3.8
-        include_literals=sys.version_info >= (3, 8),
-    ),
-    detailed_validation=...,
-)
-def test_pyyaml_unions(union_and_val: tuple, detailed_validation: bool):
-    """Native union passthrough works."""
-    converter = pyyaml_make_converter(detailed_validation=detailed_validation)
-    type, val = union_and_val
-
-    assert converter.structure(val, type) == val
-
-
-@given(detailed_validation=...)
-def test_pyyaml_dates(detailed_validation: bool):
-    """Pyyaml dates work."""
-    converter = pyyaml_make_converter(detailed_validation=detailed_validation)
-
-    @define
-    class A:
-        datetime: datetime
-        date: date
-
-    data = """
-    datetime: 1970-01-01T00:00:00Z
-    date: 1970-01-01"""
-    assert converter.loads(data, A) == A(
-        datetime(1970, 1, 1, tzinfo=timezone.utc), date(1970, 1, 1)
-    )
-
-
 @given(
     everythings(
         min_key_length=1,
@@ -698,7 +637,6 @@ def test_tomlkit_converter_unstruct_collection_overrides(everything: Everything)
         include_bytes=False,
         include_datetimes=False,
         include_bools=sys.version_info[:2] != (3, 8),  # Literal issues on 3.8
-        include_literals=sys.version_info >= (3, 8),
     ),
     detailed_validation=...,
 )
@@ -750,7 +688,6 @@ def test_cbor2_converter_unstruct_collection_overrides(everything: Everything):
     union_and_val=native_unions(
         include_datetimes=False,
         include_bools=sys.version_info[:2] != (3, 8),  # Literal issues on 3.8
-        include_literals=sys.version_info >= (3, 8),
     ),
     detailed_validation=...,
 )
@@ -760,3 +697,47 @@ def test_cbor2_unions(union_and_val: tuple, detailed_validation: bool):
     type, val = union_and_val
 
     assert converter.structure(val, type) == val
+
+
+@pytest.mark.skipif(python_implementation() == "PyPy", reason="no msgspec on PyPy")
+@given(everythings(allow_inf=False))
+def test_msgspec_json_converter(everything: Everything):
+    from cattrs.preconf.msgspec import make_converter as msgspec_make_converter
+
+    converter = msgspec_make_converter()
+    raw = converter.dumps(everything)
+    assert converter.loads(raw, Everything) == everything
+
+
+@pytest.mark.skipif(python_implementation() == "PyPy", reason="no msgspec on PyPy")
+@given(everythings(allow_inf=False))
+def test_msgspec_json_unstruct_collection_overrides(everything: Everything):
+    """Ensure collection overrides work."""
+    from cattrs.preconf.msgspec import make_converter as msgspec_make_converter
+
+    converter = msgspec_make_converter(
+        unstruct_collection_overrides={AbstractSet: sorted}
+    )
+    raw = converter.unstructure(everything)
+    assert raw["a_set"] == sorted(raw["a_set"])
+    assert raw["a_mutable_set"] == sorted(raw["a_mutable_set"])
+    assert raw["a_frozenset"] == sorted(raw["a_frozenset"])
+
+
+@pytest.mark.skipif(python_implementation() == "PyPy", reason="no msgspec on PyPy")
+@given(
+    union_and_val=native_unions(
+        include_datetimes=False,
+        include_bytes=False,
+        include_bools=sys.version_info[:2] != (3, 8),  # Literal issues on 3.8
+    ),
+    detailed_validation=...,
+)
+def test_msgspec_json_unions(union_and_val: tuple, detailed_validation: bool):
+    """Native union passthrough works."""
+    from cattrs.preconf.msgspec import make_converter as msgspec_make_converter
+
+    converter = msgspec_make_converter(detailed_validation=detailed_validation)
+    type, val = union_and_val
+
+    assert converter.structure(val, type) == val
