@@ -1,4 +1,5 @@
 """Tests for dumping."""
+
 from typing import Type
 
 from attr import asdict, astuple
@@ -111,10 +112,10 @@ def test_unstructure_hook_func(converter):
     def handle(_):
         return "hi"
 
-    class Foo(object):
+    class Foo:
         pass
 
-    class Bar(object):
+    class Bar:
         pass
 
     converter.register_unstructure_hook_func(can_handle, handle)
@@ -132,4 +133,4 @@ def test_seq_of_simple_classes_unstructure(cls_and_vals, seq_type: Type):
     inputs = seq_type(cl(*vals, **kwargs) for cl, vals, kwargs in cls_and_vals)
     outputs = converter.unstructure(inputs)
     assert type(outputs) == seq_type
-    assert all(type(e) is dict for e in outputs)
+    assert all(type(e) is dict for e in outputs)  # noqa: E721
