@@ -1,20 +1,25 @@
 """Strategies for attributes with types and classes using them."""
+
 import sys
 from collections import OrderedDict
 from collections.abc import MutableSequence as AbcMutableSequence
 from collections.abc import MutableSet as AbcMutableSet
 from collections.abc import Sequence as AbcSequence
 from collections.abc import Set as AbcSet
-from dataclasses import field, make_dataclass
+from dataclasses import field as dc_field
+from dataclasses import make_dataclass
 from functools import partial
+from pathlib import Path
 from typing import (
     Any,
     Dict,
+    Final,
     FrozenSet,
     List,
     MutableSequence,
     MutableSet,
     NewType,
+    Optional,
     Sequence,
     Set,
     Tuple,
@@ -22,14 +27,14 @@ from typing import (
     TypeVar,
 )
 
-import attr
-from attr import NOTHING, Factory, frozen
 from attr._make import _CountingAttr
+from attrs import NOTHING, Factory, field, frozen
 from hypothesis import note
 from hypothesis.strategies import (
     DrawFn,
     SearchStrategy,
     booleans,
+    characters,
     composite,
     dictionaries,
     fixed_dictionaries,
@@ -55,7 +60,14 @@ T = TypeVar("T")
 
 
 def simple_typed_classes(
-    defaults=None, min_attrs=0, frozen=False, kw_only=None, newtypes=True
+    defaults=None,
+    min_attrs=0,
+    frozen=False,
+    kw_only=None,
+    newtypes=True,
+    text_codec: str = "utf8",
+    allow_infinity=None,
+    allow_nan=None,
 ) -> SearchStrategy[Tuple[Type, PosArgs, KwArgs]]:
     """Yield tuples of (class, values)."""
     return lists_of_typed_attrs(
@@ -64,6 +76,9 @@ def simple_typed_classes(
         for_frozen=frozen,
         kw_only=kw_only,
         newtypes=newtypes,
+        text_codec=text_codec,
+        allow_infinity=allow_infinity,
+        allow_nan=allow_nan,
     ).flatmap(partial(_create_hyp_class, frozen=frozen))
 
 
@@ -94,6 +109,9 @@ def lists_of_typed_attrs(
     allow_mutable_defaults=True,
     kw_only=None,
     newtypes=True,
+    text_codec="utf8",
+    allow_infinity=None,
+    allow_nan=None,
 ) -> SearchStrategy[List[Tuple[_CountingAttr, SearchStrategy[PosArg]]]]:
     # Python functions support up to 255 arguments.
     return lists(
@@ -103,11 +121,16 @@ def lists_of_typed_attrs(
             allow_mutable_defaults=allow_mutable_defaults,
             kw_only=kw_only,
             newtypes=newtypes,
+            text_codec=text_codec,
+            allow_infinity=allow_infinity,
+            allow_nan=allow_nan,
         ),
         min_size=min_size,
         max_size=50,
     ).map(
-        lambda l: sorted(l, key=lambda t: (t[0]._default is not NOTHING, t[0].kw_only))
+        lambda lst: sorted(
+            lst, key=lambda t: (t[0]._default is not NOTHING, t[0].kw_only)
+        )
     )
 
 
@@ -117,15 +140,19 @@ def simple_typed_attrs(
     allow_mutable_defaults=True,
     kw_only=None,
     newtypes=True,
+    text_codec="utf8",
+    allow_infinity=None,
+    allow_nan=None,
 ) -> SearchStrategy[Tuple[_CountingAttr, SearchStrategy[PosArgs]]]:
     if not is_39_or_later:
         res = (
-            bare_typed_attrs(defaults, kw_only)
+            any_typed_attrs(defaults, kw_only)
             | int_typed_attrs(defaults, kw_only)
-            | str_typed_attrs(defaults, kw_only)
-            | float_typed_attrs(defaults, kw_only)
+            | str_typed_attrs(defaults, kw_only, text_codec)
+            | float_typed_attrs(defaults, kw_only, allow_infinity, allow_nan)
             | frozenset_typed_attrs(defaults, legacy_types_only=True, kw_only=kw_only)
             | homo_tuple_typed_attrs(defaults, legacy_types_only=True, kw_only=kw_only)
+            | path_typed_attrs(defaults, kw_only=kw_only)
         )
         if newtypes:
             res = (
@@ -164,12 +191,13 @@ def simple_typed_attrs(
             )
     else:
         res = (
-            bare_typed_attrs(defaults, kw_only)
+            any_typed_attrs(defaults, kw_only)
             | int_typed_attrs(defaults, kw_only)
-            | str_typed_attrs(defaults, kw_only)
-            | float_typed_attrs(defaults, kw_only)
+            | str_typed_attrs(defaults, kw_only, text_codec)
+            | float_typed_attrs(defaults, kw_only, allow_infinity, allow_nan)
             | frozenset_typed_attrs(defaults, kw_only=kw_only)
             | homo_tuple_typed_attrs(defaults, kw_only=kw_only)
+            | path_typed_attrs(defaults, kw_only=kw_only)
         )
         if newtypes:
             res = (
@@ -206,7 +234,7 @@ def _create_hyp_class(
     """
 
     def key(t):
-        return (t[0]._default is not attr.NOTHING, t[0].kw_only)
+        return (t[0]._default is not NOTHING, t[0].kw_only)
 
     attrs_and_strat = sorted(attrs_and_strategy, key=key)
     attrs = [a[0] for a in attrs_and_strat]
@@ -214,13 +242,27 @@ def _create_hyp_class(
         a.counter = i
     vals = tuple((a[1]) for a in attrs_and_strat if not a[0].kw_only)
     note(f"Class fields: {attrs}")
-    attrs_dict = OrderedDict(zip(gen_attr_names(), attrs))
+    attrs_dict = {}
+
+    names = gen_attr_names()
     kwarg_strats = {}
-    for attr_name, attr_and_strat in zip(gen_attr_names(), attrs_and_strat):
-        if attr_and_strat[0].kw_only:
-            if attr_name.startswith("_"):
-                attr_name = attr_name[1:]
-            kwarg_strats[attr_name] = attr_and_strat[1]
+
+    for ix, (attribute, strat) in enumerate(attrs_and_strat):
+        name = next(names)
+        attrs_dict[name] = attribute
+        if ix % 2 == 1:
+            # Every third attribute gets an alias, the next attribute name.
+            alias = next(names)
+            attribute.alias = alias
+            name = alias
+        else:
+            # No alias.
+            if name[0] == "_":
+                name = name[1:]
+
+        if attribute.kw_only:
+            kwarg_strats[name] = strat
+    note(f"Attributes: {attrs_dict}")
 
     return tuples(
         just(make_class("HypAttrsClass", attrs_dict, frozen=frozen)),
@@ -241,7 +283,7 @@ def _create_dataclass(
     """
 
     def key(t):
-        return t[0]._default is not attr.NOTHING
+        return t[0]._default is not NOTHING
 
     attrs_and_strat = sorted(attrs_and_strategy, key=key)
     attrs = [a[0] for a in attrs_and_strat]
@@ -253,12 +295,18 @@ def _create_dataclass(
             make_dataclass(
                 "HypDataclass",
                 [
-                    (n, a.type)
-                    if a._default is NOTHING
-                    else (
-                        (n, a.type, field(default=a._default))
-                        if not isinstance(a._default, Factory)
-                        else (n, a.type, field(default_factory=a._default.factory))
+                    (
+                        (n, a.type)
+                        if a._default is NOTHING
+                        else (
+                            (n, a.type, dc_field(default=a._default))
+                            if not isinstance(a._default, Factory)
+                            else (
+                                n,
+                                a.type,
+                                dc_field(default_factory=a._default.factory),
+                            )
+                        )
                     )
                     for n, a in zip(gen_attr_names(), attrs)
                 ],
@@ -274,7 +322,7 @@ def _create_hyp_class_and_strat(
     attrs_and_strategy: List[Tuple[_CountingAttr, SearchStrategy[PosArg]]]
 ) -> SearchStrategy[Tuple[Type, SearchStrategy[PosArgs], SearchStrategy[KwArgs]]]:
     def key(t):
-        return (t[0].default is not attr.NOTHING, t[0].kw_only)
+        return (t[0].default is not NOTHING, t[0].kw_only)
 
     attrs_and_strat = sorted(attrs_and_strategy, key=key)
     attrs = [a[0] for a in attrs_and_strat]
@@ -295,16 +343,15 @@ def _create_hyp_class_and_strat(
 
 
 @composite
-def bare_typed_attrs(draw, defaults=None, kw_only=None):
-    """
-    Generate a tuple of an attribute and a strategy that yields values
-    appropriate for that attribute.
-    """
-    default = attr.NOTHING
+def any_typed_attrs(
+    draw: DrawFn, defaults=None, kw_only=None
+) -> Tuple[_CountingAttr, SearchStrategy[None]]:
+    """Attributes typed as `Any`, having values of `None`."""
+    default = NOTHING
     if defaults is True or (defaults is None and draw(booleans())):
         default = None
     return (
-        attr.ib(
+        field(
             type=Any,
             default=default,
             kw_only=draw(booleans()) if kw_only is None else kw_only,
@@ -319,11 +366,11 @@ def int_typed_attrs(draw, defaults=None, kw_only=None):
     Generate a tuple of an attribute and a strategy that yields ints for that
     attribute.
     """
-    default = attr.NOTHING
+    default = NOTHING
     if defaults is True or (defaults is None and draw(booleans())):
         default = draw(integers())
     return (
-        attr.ib(
+        field(
             type=int,
             default=default,
             kw_only=draw(booleans()) if kw_only is None else kw_only,
@@ -333,7 +380,7 @@ def int_typed_attrs(draw, defaults=None, kw_only=None):
 
 
 @composite
-def str_typed_attrs(draw, defaults=None, kw_only=None):
+def str_typed_attrs(draw, defaults=None, kw_only=None, codec: str = "utf8"):
     """
     Generate a tuple of an attribute and a strategy that yields strs for that
     attribute.
@@ -342,31 +389,56 @@ def str_typed_attrs(draw, defaults=None, kw_only=None):
     if defaults is True or (defaults is None and draw(booleans())):
         default = draw(text())
     return (
-        attr.ib(
+        field(
             type=str,
             default=default,
             kw_only=draw(booleans()) if kw_only is None else kw_only,
         ),
-        text(),
+        text(characters(codec=codec)),
     )
 
 
 @composite
-def float_typed_attrs(draw, defaults=None, kw_only=None):
+def float_typed_attrs(
+    draw, defaults=None, kw_only=None, allow_infinity=None, allow_nan=None
+):
     """
     Generate a tuple of an attribute and a strategy that yields floats for that
     attribute.
     """
-    default = attr.NOTHING
+    default = NOTHING
     if defaults is True or (defaults is None and draw(booleans())):
-        default = draw(floats())
+        default = draw(floats(allow_infinity=allow_infinity, allow_nan=allow_nan))
     return (
-        attr.ib(
+        field(
             type=float,
             default=default,
             kw_only=draw(booleans()) if kw_only is None else kw_only,
         ),
-        floats(),
+        floats(allow_infinity=allow_infinity, allow_nan=allow_nan),
+    )
+
+
+@composite
+def path_typed_attrs(
+    draw: DrawFn, defaults: Optional[bool] = None, kw_only: Optional[bool] = None
+) -> Tuple[_CountingAttr, SearchStrategy[Path]]:
+    """
+    Generate a tuple of an attribute and a strategy that yields paths for that
+    attribute.
+    """
+    from string import ascii_lowercase
+
+    default = NOTHING
+    if defaults is True or (defaults is None and draw(booleans())):
+        default = Path(draw(text(ascii_lowercase, min_size=1)))
+    return (
+        field(
+            type=Path,
+            default=default,
+            kw_only=draw(booleans()) if kw_only is None else kw_only,
+        ),
+        text(ascii_lowercase, min_size=1).map(Path),
     )
 
 
@@ -379,7 +451,7 @@ def dict_typed_attrs(
     for that attribute. The dictionaries map strings to integers.
     The generated dict types are what's expected to be used on pre-3.9 Pythons.
     """
-    default = attr.NOTHING
+    default = NOTHING
     val_strat = dictionaries(keys=text(), values=integers())
     if defaults is True or (defaults is None and draw(booleans())):
         default_val = draw(val_strat)
@@ -389,7 +461,7 @@ def dict_typed_attrs(
             default = default_val
     type = draw(sampled_from([Dict[str, int], Dict, dict]))
     return (
-        attr.ib(
+        field(
             type=type,
             default=default,
             kw_only=draw(booleans()) if kw_only is None else kw_only,
@@ -408,7 +480,7 @@ def new_dict_typed_attrs(
 
     Uses the new 3.9 dict annotation.
     """
-    default_val = attr.NOTHING
+    default_val = NOTHING
     val_strat = dictionaries(keys=text(), values=integers())
     if defaults is True or (defaults is None and draw(booleans())):
         default_val = draw(val_strat)
@@ -420,7 +492,7 @@ def new_dict_typed_attrs(
         default = default_val
 
     return (
-        attr.ib(
+        field(
             type=dict[str, int],
             default=default,
             kw_only=draw(booleans()) if kw_only is None else kw_only,
@@ -441,7 +513,7 @@ def set_typed_attrs(
     Generate a tuple of an attribute and a strategy that yields sets
     for that attribute. The sets contain integers.
     """
-    default_val = attr.NOTHING
+    default_val = NOTHING
     val_strat = sets(integers())
     if defaults is True or (defaults is None and draw(booleans())):
         default_val = draw(val_strat)
@@ -460,7 +532,7 @@ def set_typed_attrs(
         )
     )
     return (
-        attr.ib(
+        field(
             type=type,
             default=default,
             kw_only=draw(booleans()) if kw_only is None else kw_only,
@@ -477,7 +549,7 @@ def frozenset_typed_attrs(
     Generate a tuple of an attribute and a strategy that yields frozensets
     for that attribute. The frozensets contain integers.
     """
-    default = attr.NOTHING
+    default = NOTHING
     val_strat = frozensets(integers())
     if defaults is True or (defaults is None and draw(booleans())):
         default = draw(val_strat)
@@ -489,7 +561,7 @@ def frozenset_typed_attrs(
         )
     )
     return (
-        attr.ib(
+        field(
             type=type,
             default=default,
             kw_only=draw(booleans()) if kw_only is None else kw_only,
@@ -505,12 +577,12 @@ def list_typed_attrs(
     allow_mutable_defaults=True,
     legacy_types_only=False,
     kw_only=None,
-):
+) -> Tuple[_CountingAttr, SearchStrategy[List[float]]]:
     """
     Generate a tuple of an attribute and a strategy that yields lists
     for that attribute. The lists contain floats.
     """
-    default_val = attr.NOTHING
+    default_val = NOTHING
     val_strat = lists(floats(allow_infinity=False, allow_nan=False))
     if defaults is True or (defaults is None and draw(booleans())):
         default_val = draw(val_strat)
@@ -521,10 +593,10 @@ def list_typed_attrs(
     else:
         default = default_val
     return (
-        attr.ib(
+        field(
             type=draw(
                 sampled_from(
-                    [list[float], list, List[float], List]
+                    [list[float], list, List[float], List, Final[list[float]]]
                     if not legacy_types_only
                     else [List, List[float], list]
                 )
@@ -548,7 +620,7 @@ def seq_typed_attrs(
     Generate a tuple of an attribute and a strategy that yields lists
     for that attribute. The lists contain integers.
     """
-    default_val = attr.NOTHING
+    default_val = NOTHING
     val_strat = lists(integers())
     if defaults is True or (defaults is None and draw(booleans())):
         default_val = draw(val_strat)
@@ -560,7 +632,7 @@ def seq_typed_attrs(
         default = default_val
 
     return (
-        attr.ib(
+        field(
             type=AbcSequence[int] if not legacy_types_only else Sequence[int],
             default=default,
             kw_only=draw(booleans()) if kw_only is None else kw_only,
@@ -581,7 +653,7 @@ def mutable_seq_typed_attrs(
     Generate a tuple of an attribute and a strategy that yields lists
     for that attribute. The lists contain floats.
     """
-    default_val = attr.NOTHING
+    default_val = NOTHING
     val_strat = lists(floats(allow_infinity=False, allow_nan=False))
     if defaults is True or (defaults is None and draw(booleans())):
         default_val = draw(val_strat)
@@ -593,10 +665,12 @@ def mutable_seq_typed_attrs(
         default = default_val
 
     return (
-        attr.ib(
-            type=AbcMutableSequence[float]
-            if not legacy_types_only
-            else MutableSequence[float],
+        field(
+            type=(
+                AbcMutableSequence[float]
+                if not legacy_types_only
+                else MutableSequence[float]
+            ),
             default=default,
             kw_only=draw(booleans()) if kw_only is None else kw_only,
         ),
@@ -610,12 +684,12 @@ def homo_tuple_typed_attrs(draw, defaults=None, legacy_types_only=False, kw_only
     Generate a tuple of an attribute and a strategy that yields homogenous
     tuples for that attribute. The tuples contain strings.
     """
-    default = attr.NOTHING
+    default = NOTHING
     val_strat = tuples(text(), text(), text())
     if defaults is True or (defaults is None and draw(booleans())):
         default = draw(val_strat)
     return (
-        attr.ib(
+        field(
             type=draw(
                 sampled_from(
                     [tuple[str, ...], tuple, Tuple, Tuple[str, ...]]
@@ -636,13 +710,13 @@ def newtype_int_typed_attrs(draw: DrawFn, defaults=None, kw_only=None):
     Generate a tuple of an attribute and a strategy that yields ints for that
     attribute.
     """
-    default = attr.NOTHING
+    default = NOTHING
     if defaults is True or (defaults is None and draw(booleans())):
         default = draw(integers())
-    type = NewType("NewInt", int)
+    NewInt = NewType("NewInt", int)
     return (
-        attr.ib(
-            type=type,
+        field(
+            type=NewInt,
             default=default,
             kw_only=draw(booleans()) if kw_only is None else kw_only,
         ),
@@ -656,7 +730,7 @@ def newtype_attrs_typed_attrs(draw: DrawFn, defaults=None, kw_only=None):
     Generate a tuple of an attribute and a strategy that yields values for that
     attribute.
     """
-    default = attr.NOTHING
+    default = NOTHING
 
     @frozen
     class NewTypeAttrs:
@@ -665,10 +739,10 @@ def newtype_attrs_typed_attrs(draw: DrawFn, defaults=None, kw_only=None):
     if defaults is True or (defaults is None and draw(booleans())):
         default = NewTypeAttrs(draw(integers()))
 
-    type = NewType("NewAttrs", NewTypeAttrs)
+    NewAttrs = NewType("NewAttrs", NewTypeAttrs)
     return (
-        attr.ib(
-            type=type,
+        field(
+            type=NewAttrs,
             default=default,
             kw_only=draw(booleans()) if kw_only is None else kw_only,
         ),
@@ -685,11 +759,11 @@ def just_class(
     nested_cl = tup[1][0]
     nested_cl_args = tup[1][1]
     nested_cl_kwargs = tup[1][2]
-    default = attr.Factory(lambda: nested_cl(*defaults[0], **defaults[1]))
+    default = Factory(lambda: nested_cl(*defaults[0], **defaults[1]))
     combined_attrs = list(tup[0])
     combined_attrs.append(
         (
-            attr.ib(type=nested_cl, default=default),
+            field(type=nested_cl, default=default),
             just(nested_cl(*nested_cl_args, **nested_cl_kwargs)),
         )
     )
@@ -705,11 +779,11 @@ def list_of_class(
     nested_cl = tup[1][0]
     nested_cl_args = tup[1][1]
     nested_cl_kwargs = tup[1][2]
-    default = attr.Factory(lambda: [nested_cl(*defaults[0], **defaults[1])])
+    default = Factory(lambda: [nested_cl(*defaults[0], **defaults[1])])
     combined_attrs = list(tup[0])
     combined_attrs.append(
         (
-            attr.ib(type=List[nested_cl], default=default),
+            field(type=List[nested_cl], default=default),
             just([nested_cl(*nested_cl_args, **nested_cl_kwargs)]),
         )
     )
@@ -726,11 +800,11 @@ def new_list_of_class(
     nested_cl = tup[1][0]
     nested_cl_args = tup[1][1]
     nested_cl_kwargs = tup[1][2]
-    default = attr.Factory(lambda: [nested_cl(*defaults[0], **defaults[1])])
+    default = Factory(lambda: [nested_cl(*defaults[0], **defaults[1])])
     combined_attrs = list(tup[0])
     combined_attrs.append(
         (
-            attr.ib(type=list[nested_cl], default=default),
+            field(type=list[nested_cl], default=default),
             just([nested_cl(*nested_cl_args, **nested_cl_kwargs)]),
         )
     )
@@ -746,11 +820,11 @@ def dict_of_class(
     nested_cl = tup[1][0]
     nested_cl_args = tup[1][1]
     nested_cl_kwargs = tup[1][2]
-    default = attr.Factory(lambda: {"cls": nested_cl(*defaults[0], **defaults[1])})
+    default = Factory(lambda: {"cls": nested_cl(*defaults[0], **defaults[1])})
     combined_attrs = list(tup[0])
     combined_attrs.append(
         (
-            attr.ib(type=Dict[str, nested_cl], default=default),
+            field(type=Dict[str, nested_cl], default=default),
             just({"cls": nested_cl(*nested_cl_args, **nested_cl_kwargs)}),
         )
     )
@@ -771,9 +845,7 @@ def _create_hyp_nested_strategy(
     # A strategy producing tuples of the form ([list of attributes], <given
     # class strategy>).
     attrs_and_classes: SearchStrategy[
-        Tuple[
-            List[Tuple[_CountingAttr, PosArgs]], Tuple[Type, SearchStrategy[PosArgs]],
-        ]
+        Tuple[List[Tuple[_CountingAttr, PosArgs]], Tuple[Type, SearchStrategy[PosArgs]]]
     ] = tuples(
         lists_of_typed_attrs(kw_only=kw_only, newtypes=newtypes), simple_class_strategy
     )
@@ -810,16 +882,12 @@ def nested_classes(
             )
             | just_class((attrs, (cls, init_vals, init_kwargs)), (pos_defs, kwarg_defs))
         )
-    else:
-        return draw(
-            list_of_class(
-                (attrs, (cls, init_vals, init_kwargs)), (pos_defs, kwarg_defs)
-            )
-            | dict_of_class(
-                (attrs, (cls, init_vals, init_kwargs)), (pos_defs, kwarg_defs)
-            )
-            | just_class((attrs, (cls, init_vals, init_kwargs)), (pos_defs, kwarg_defs))
-        )
+
+    return draw(
+        list_of_class((attrs, (cls, init_vals, init_kwargs)), (pos_defs, kwarg_defs))
+        | dict_of_class((attrs, (cls, init_vals, init_kwargs)), (pos_defs, kwarg_defs))
+        | just_class((attrs, (cls, init_vals, init_kwargs)), (pos_defs, kwarg_defs))
+    )
 
 
 def nested_typed_classes_and_strat(
